ideogramOverline property
String
get
ideogramOverline
Ideogram overline, or a line down the left side — IDEOGRAM_OVERLINE.
Implementation
String get ideogramOverline => _wrap(IDEOGRAM_OVERLINE);
Ideogram overline, or a line down the left side — IDEOGRAM_OVERLINE.
String get ideogramOverline => _wrap(IDEOGRAM_OVERLINE);