ideogramUnderline property
String
get
ideogramUnderline
Ideogram underline, or a line down the right side — IDEOGRAM_UNDERLINE.
Implementation
String get ideogramUnderline => _wrap(IDEOGRAM_UNDERLINE);
Ideogram underline, or a line down the right side — IDEOGRAM_UNDERLINE.
String get ideogramUnderline => _wrap(IDEOGRAM_UNDERLINE);