endOffset property
End offset of the selection (inclusive).
This is the index of the last selected byte in the data array. For a single-byte selection, endOffset equals startOffset.
Implementation
final int endOffset;
End offset of the selection (inclusive).
This is the index of the last selected byte in the data array. For a single-byte selection, endOffset equals startOffset.
final int endOffset;