startOffset property
Start offset of the selection (inclusive).
This is the index of the first selected byte in the data array. For a single-byte selection, startOffset equals endOffset.
Implementation
final int startOffset;
Start offset of the selection (inclusive).
This is the index of the first selected byte in the data array. For a single-byte selection, startOffset equals endOffset.
final int startOffset;