HexLine class

Represents a single line in the hex viewer

Constructors

HexLine({required int offset, required List<int> bytes, required String hexString, required String asciiString})
const

Properties

asciiString String
ASCII representation (e.g., "Hello Wor")
final
bytes List<int>
Raw bytes for this line
final
hashCode int
The hash code for this object.
no setterinherited
hexString String
Formatted hex string (e.g., "48 65 6C 6C 6F | 20 57 6F 72")
final
offset int
Offset of the first byte in this line
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited